export interface IndyCredProposeOptions {
    schemaIssuerDid?: string;
    schemaId?: string;
    schemaName?: string;
    schemaVersion?: string;
    credentialDefinitionId?: string;
    issuerDid?: string;
}
/**
 * Class providing validation for the V2 credential proposal payload.
 *
 * The v1 message contains the properties directly in the message, which means they are
 * validated using the class validator decorators. In v2 the attachments content is not transformed
 * when transforming the message to a class instance so the content is not verified anymore, hence this
 * class.
 *
 */
export declare class IndyCredPropose {
    constructor(options: IndyCredProposeOptions);
    /**
     * Filter to request credential based on a particular Schema issuer DID.
     */
    schemaIssuerDid?: string;
    /**
     * Filter to request credential based on a particular Schema.
     */
    schemaId?: string;
    /**
     * Filter to request credential based on a schema name.
     */
    schemaName?: string;
    /**
     * Filter  to request credential based on a schema version.
     */
    schemaVersion?: string;
    /**
     * Filter to request credential based on a particular Credential Definition.
     */
    credentialDefinitionId?: string;
    /**
     * Filter to request a credential issued by the owner of a particular DID.
     */
    issuerDid?: string;
}
